@@ -171,20 +171,10 @@ compare_areas <- function(data, area, value,
 #' library(dplyr)
 #' region <- "North East region"
 #' top_names <- c("England", region)
-#' dfdom <- fingertips_data(DomainID = 1938132762) %>%
-#' group_by(IndicatorID) %>%
-#'         filter(((IndicatorID == 41001 &
-#'                          Timeperiod == "2014 - 16" &
-#'                          Sex == "Persons") |
-#'                         (IndicatorID == 91393 &
-#'                                  Timeperiod == "2011 - 15" &
-#'                                  Sex == "Female") |
-#'                         (IndicatorID == 92607 &
-#'                                  Timeperiod == "2016" &
-#'                                  Sex == "Not applicable")) &
-#'                        (AreaName %in% top_names |
-#'                                 ParentName == region)) %>%
-#'         ungroup() %>%
+#' dfdom <- fingertips_data(DomainID = 1938133060) %>%
+#'         filter(Timeperiod == "2016",
+#'                Age == "All ages",
+#'                (AreaName %in% top_names | ParentName == region)) %>%
 #'         mutate(Value = round(Value, 1))
 #' p <- overview(dfdom,
 #'               area = AreaName,
@@ -704,6 +694,7 @@ box_plots <- function(data, timeperiod, value,
 #' @param copyright_size number; determine size of the copyright text
 #' @param name_for_label if interactive map, name of field containing area names
 #'   to be used for label (unquoted) - optional
+#' @param fill field to be used to determine the colouring of the areas (unquoted)
 #' @family quick charts
 #' @import ggplot2
 #' @import dplyr
@@ -768,9 +759,12 @@ map <- function(data, ons_api, area_code, fill, type = "static", value, name_for
                               by.y = quo_text(area_code),
                               all.x = TRUE)
                 copyright <- data.frame(val = paste0("Contains Ordnance Survey data\n",
-                                                     "\uA9 Crown copyright and database right 2017.\n",
+                                                     paste0("\uA9 Crown copyright and database right ",
+                                                            format(Sys.Date(), "%Y")),
+                                                            "\n",
                                                      "Contains National Statistics data\n",
-                                                     "\uA9 Crown copyright and database right 2017."),
+                                                     paste0("\uA9 Crown copyright and database right ",
+                                                            format(Sys.Date(), "%Y"))),
                                         x = max(shp$long),
                                         y = min(shp$lat))
                 map <- ggplot(shp) +
@@ -941,17 +935,9 @@ map <- function(data, ons_api, area_code, fill, type = "static", value, name_for
 #' # This example is untested because of the time required to retrieve the data
 #' library(fingertipsR)
 #' library(dplyr)
-#' df <- fingertips_data(DomainID = 1938132762,
-#'                       rank = TRUE) %>%
-#'         filter(((IndicatorID == 41001 &
-#'                          Timeperiod == "2014 - 16" &
-#'                          Sex == "Persons") |
-#'                         (IndicatorID == 91393 &
-#'                                  Timeperiod == "2011 - 15" &
-#'                                  Sex == "Female") |
-#'                         (IndicatorID == 92607 &
-#'                                  Timeperiod == "2016" &
-#'                                  Sex == "Not applicable")))
+#' df <- fingertips_data(DomainID = 1938133060, rank = TRUE) %>%
+#' filter(Timeperiod == "2016",
+#'        Age == "All ages")
 #' p <- area_profiles(df,
 #'                    value = Value,
 #'                    count = Count,
